@@ -109,7 +109,9 @@ puts nodeinfo.to_json""" % (env, tier)
                                               aws_access_key_id=creds["access"],
                                               aws_secret_access_key=creds["secret"])
 
-            cw_obj = boto.ec2.cloudwatch.connect_to_region('us-east-1')
+            cw_obj = boto.ec2.cloudwatch.connect_to_region('us-east-1',
+                                              aws_access_key_id=creds["access"],
+                                              aws_secret_access_key=creds["secret"])
             nodes = self.nodes(env_name)
             for node in nodes:
                 i = conn.get_only_instances(node)
